@@ -72,9 +72,26 @@ Boston, MA 02111-1307, USA.
 #define GUINT32_TO_GPOINTER GUINT_TO_POINTER
 #define GPOINTER_TO_GUINT32 GPOINTER_TO_UINT
 
-/* Directory colors */
+/* Directory colors and styles */
 #define GNOMAD_DIRECTORY_FILE_ENTRY_COLOR    "black"
+#define GNOMAD_DIRECTORY_FILE_ENTRY_WEIGHT   NULL
+#define GNOMAD_DIRECTORY_FILE_ENTRY_STYLE    NULL
 #define GNOMAD_DIRECTORY_FOLDER_ENTRY_COLOR  "blue"
+#define GNOMAD_DIRECTORY_FOLDER_ENTRY_WEIGHT "bold"
+#define GNOMAD_DIRECTORY_FOLDER_ENTRY_STYLE  NULL
+/* 
+ * Example high contrast colors and style.
+ * comment these in and comment out the lines above
+ * to activate a high-visibility style.
+ */
+/*
+#define GNOMAD_DIRECTORY_FILE_ENTRY_COLOR    "green"
+#define GNOMAD_DIRECTORY_FILE_ENTRY_WEIGHT   PANGO_WEIGHT_BOLD
+#define GNOMAD_DIRECTORY_FILE_ENTRY_STYLE    NULL
+#define GNOMAD_DIRECTORY_FOLDER_ENTRY_COLOR  "green"
+#define GNOMAD_DIRECTORY_FOLDER_ENTRY_WEIGHT PANGO_WEIGHT_BOLD
+#define GNOMAD_DIRECTORY_FOLDER_ENTRY_STYLE  PANGO_STYLE_ITALIC
+*/
 
 /* Globally useful structures */
 
