@@ -234,9 +234,14 @@ static void edit_ok_click ( GtkButton *button,
          /*
           * g_print("Updating: %s\n", newmeta->path);
           * dump_metadata_t(newmeta);
-          */	 
+          */
          if(!strcmp(newmeta->codec, "MP3"))
-            set_tag_for_mp3file(newmeta, TRUE);
+#if defined(HAVE_TAGLIB) && defined(TAGLIB_ONLY)
+	   set_tag_for_file(newmeta, TRUE);
+#else
+           set_tag_for_mp3file(newmeta, TRUE);
+#endif
+
 #ifdef HAVE_TAGLIB
          else if(!strcmp(newmeta->codec, "OGG") || !strcmp(newmeta->codec, "FLAC"))
             set_tag_for_file(newmeta, TRUE);
@@ -342,7 +347,7 @@ static void edit_dialog_create(void)
 			      GNOME_STOCK_BUTTON_OK,
 			      NULL);
   } else {
-    dialog = gnome_dialog_new(_("Edit track metadata (ID3v2)"),
+    dialog = gnome_dialog_new(_("Edit track metadata"),
 			      GNOME_STOCK_BUTTON_CANCEL,
 			      GNOME_STOCK_BUTTON_OK,
 			      NULL);
@@ -360,7 +365,7 @@ static void edit_dialog_create(void)
     dialog = gtk_dialog_new_with_buttons(_("Edit jukebox file metadata"),
 					 NULL, 0, NULL);
   } else {
-    dialog = gtk_dialog_new_with_buttons(_("Edit track metadata (ID3v2)"),
+    dialog = gtk_dialog_new_with_buttons(_("Edit track metadata"),
 					 NULL, 0, NULL);
   }
   
