@@ -479,7 +479,11 @@ static GList *get_metadata_for_dirlist(GList *inlist,
 	  if (gnomad_debug != 0) {
 	    g_print("Getting ID3 info for: %s\n", meta->filename);
 	  }
+#if defined(HAVE_TAGLIB) && defined(TAGLIB_ONLY)
+	  get_tag_for_file(meta);
+#else
 	  get_tag_for_mp3file(meta);
+	  /* FIXME: use taglib to do this, if it is available. */
 	  /* Scans the mp3 frames to calculate play length */
 	  if ((meta->length == NULL) && (meta->path != NULL)) {
 	    // g_print("Calling length_from_file()...\n");
@@ -487,6 +491,7 @@ static GList *get_metadata_for_dirlist(GList *inlist,
 	    meta->length = length_from_file(tmppath, meta->size);
 	    g_free(tmppath);
 	  }
+#endif
 	}
 	if (!strcmp(meta->codec,"WAV")) {
 	  /* FIXME: learn how to read metadata from WAV files */
@@ -817,7 +822,14 @@ gint delete_files(GList *filelist)
     /* g_print("Deleting: %s\n", meta->path); */
     tmp = filename_fromutf8(meta->path);
 
-    if (g_file_test(tmp, G_FILE_TEST_IS_DIR)) remove_dir_contents(tmp);
+    /* Skip past current and parent directory if selected */
+    if (!strcmp(tmp, ".") || !strcmp(tmp, "..")) {
+      continue;
+    }
+    
+    if (g_file_test(tmp, G_FILE_TEST_IS_DIR)) {
+      remove_dir_contents(tmp);
+    }
 
 #if !GLIB_CHECK_VERSION(2,6,0)
     c += remove(tmp);
@@ -831,8 +843,10 @@ gint delete_files(GList *filelist)
   return c;
 }
 
-/* Copy an MP3 file and remove the tag */
-gboolean clone_and_strip_id3(const gchar * const source, const gchar * const dest)
+/* Copy a file and remove the tag */
+gboolean clone_and_strip_tag(const gchar * const source, 
+			     const gchar * const dest, 
+			     const gchar * const codec)
 {
   gchar *tmpsource, *tmpdest;
 
@@ -841,7 +855,18 @@ gboolean clone_and_strip_id3(const gchar * const source, const gchar * const des
   if (copy_file(tmpsource, tmpdest)) {
     /* Next strip the tag */
     /* g_print("Stripping tag from %s\n", dest); */
-    remove_tag_from_mp3file(tmpdest);
+    if (!strcmp(codec, "MP3")) {
+#if defined(HAVE_TAGLIB) && defined(TAGLIB_ONLY)
+      remove_tag_from_file(tmpdest);
+#else
+      remove_tag_from_mp3file(tmpdest);
+#endif
+    }
+#ifdef HAVE_TAGLIB
+    else if (!strcmp(codec, "OGG") || !strcmp(codec, "FLAC")) {
+      remove_tag_from_file(tmpdest);
+    }
+#endif
     g_free(tmpsource);
     g_free(tmpdest);
     return TRUE;
