@@ -32,6 +32,9 @@ Boston, MA 02111-1307, USA.
 #include <dbus/dbus.h>
 #include <dbus/dbus-glib-lowlevel.h>
 #endif
+#ifdef HAVE_HAL
+#include <hal/libhal.h>
+#endif
 
 /* This one should be global really */
 GtkWidget *main_window;
@@ -48,9 +51,12 @@ static GtkWidget *jukebox_menu;
 #endif
 // The expose() event will be treated JUST ONCE at the first window creation
 static gboolean justonce = TRUE;
-#ifdef HAVE_DBUSGLIB
-DBusConnection *dbus_conn;
+#if defined(HAVE_DBUSGLIB) && defined(HAVE_HAL)
+DBusConnection *dbus_session_conn;
+DBusConnection *dbus_system_conn;
 DBusError dbus_error;
+LibHalContext *hal_context;
+char *global_udistr = NULL;
 #endif
 
 
@@ -68,6 +74,7 @@ static gint delete(GtkWidget *widget,
   }
   write_prefs_file();
   jukebox_release();
+
   gtk_main_quit();
   return FALSE;
 }
@@ -449,6 +456,55 @@ static void information_dialog(gpointer data)
   }
 }
 
+#if defined(HAVE_DBUSGLIB) && defined(HAVE_HAL)
+static void
+hal_device_added (LibHalContext *context, const char *udi)
+{
+  int vendor_id;
+  int product_id;
+  char *protocol;
+
+  vendor_id = libhal_device_get_property_int (context, udi, "usb.vendor_id", NULL);
+  product_id = libhal_device_get_property_int (context, udi, "usb.product_id", NULL);
+  protocol = libhal_device_get_property_string (context, udi, "portable_audio_player.type", NULL);
+  if (protocol == NULL) {
+    protocol = libhal_device_get_property_string (context, udi, "portable_audio_player.libnjb.protocol", NULL);
+  }
+
+  if (protocol != NULL) {
+    g_print("Detected connected device VID=0x%04x/PID=0x%04x, protocol: %s\n", vendor_id, product_id, protocol);
+    g_print("UDI: %s\n", udi);
+    if (!strcmp(protocol, "mtp") || !strcmp(protocol, "pde") || !strcmp(protocol, "oasis")) {
+      // If we haven't yet selected a jukebox, take this one!
+      if (!jukebox_selected()) {
+	global_udistr = strdup(udi);
+	scan_jukebox(NULL);
+      }
+    }
+  }
+
+  libhal_free_string(protocol);
+}
+
+static void
+hal_device_removed (LibHalContext *context, const char *udi)
+{
+  int vendor_id;
+  int product_id;
+
+  vendor_id = libhal_device_get_property_int (context, udi, "usb.vendor_id", NULL);
+  product_id = libhal_device_get_property_int (context, udi, "usb.product_id", NULL);
+
+  if (global_udistr != NULL && !strcmp(udi, global_udistr)) {
+    g_print("Device VID=0x%04x/PID=0x%04x detached.\n", vendor_id, product_id);
+    g_print("UDI: %s\n", udi);
+    jukebox_release();
+    free(global_udistr);
+    global_udistr = NULL;
+  }
+}
+#endif
+
 /***********************************************************************************/
 /* And this is where everything starts, everything graphic is initialized etc      */
 /***********************************************************************************/
@@ -664,25 +720,55 @@ int main(int argc,
   gtk_menu_shell_append(GTK_MENU_SHELL(menu_bar), root_menu);
 
 #ifdef HAVE_DBUSGLIB
+  // Connect to the SESSION bus to broadcast events and stuff.
   dbus_error_init(&dbus_error);
-
-  // Open D-BUS connection
-  dbus_conn = dbus_bus_get(DBUS_BUS_SESSION, &dbus_error);
-  if (dbus_conn == NULL) {
-    g_printerr ("Failed to open connection to D-BUS bus\n");
+  dbus_session_conn = dbus_bus_get(DBUS_BUS_SESSION, &dbus_error);
+  if (dbus_session_conn == NULL) {
+    g_printerr ("Failed to open connection to D-BUS SESSION bus\n");
   } else {
     DBusMessage *message;
 
-    dbus_connection_setup_with_g_main(dbus_conn, NULL);
+    dbus_connection_setup_with_g_main(dbus_session_conn, NULL);
     message = dbus_message_new_signal ("/net/sourceforge/gnomad2",
 				       "net.sourceforge.gnomad2", 
 				       "DeviceStatus");
     // Append the string "Online" to the signal
     //dbus_message_append_args(message,DBUS_TYPE_STRING,"Online",DBUS_TYPE_INVALID);
-    dbus_connection_send(dbus_conn, message, NULL);
+    dbus_connection_send(dbus_session_conn, message, NULL);
     dbus_message_unref(message);
   }
   dbus_error_free(&dbus_error);
+
+#endif
+
+#if defined(HAVE_DBUSGLIB) && defined(HAVE_HAL)
+  // Connect to the SYSTEM bus to detect devices and stuff.
+  dbus_error_init(&dbus_error);
+  dbus_system_conn = dbus_bus_get(DBUS_BUS_SYSTEM, &dbus_error);
+  if (dbus_system_conn == NULL) {
+    g_printerr ("Failed to open connection to D-BUS SYSTEM bus\n");
+  } else {
+    dbus_connection_setup_with_g_main(dbus_system_conn, NULL);
+    // dbus_system_proxy = dbus_g_proxy_new_for_name (dbus_system_conn,
+    //					   "org.freedesktop.Hal",
+    //					   "/",
+    //					   "org.freedesktop.Hal.Device");
+    // g_object_unref (dbus_system_proxy);
+    hal_context = libhal_ctx_new ();
+    if (hal_context == NULL) {
+      g_print("Couldn't create HAL context!\n");
+    } else {
+      //libhal_ctx_set_user_data (hal_context, (void *) NULL);
+      libhal_ctx_set_dbus_connection (hal_context, dbus_system_conn);
+      libhal_ctx_set_device_added (hal_context, hal_device_added);
+      libhal_ctx_set_device_removed (hal_context, hal_device_removed);
+      libhal_device_property_watch_all (hal_context, &dbus_error);
+      if (!libhal_ctx_init (hal_context, &dbus_error)) {
+	g_print("error: libhal_ctx_init: %s: %s\n", dbus_error.name, dbus_error.message);
+      }
+    }
+  }
+  dbus_error_free(&dbus_error);
 #endif
   
   gtk_widget_show(main_window);
