@@ -28,6 +28,10 @@ Boston, MA 02111-1307, USA.
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
+#if GLIB_CHECK_VERSION(2,6,0)	/* perhaps only needed in this case?? */
+#   include <glib.h>
+#   include <glib/gstdio.h>
+#endif
 
 /* Eventually make charset selectable */
 
@@ -47,72 +51,6 @@ static id3_latin1_t *charset_from_utf8(const id3_utf8_t *str)
   return (id3_latin1_t *) tmp;
 }
 
-/**
- * This function checks if a given file has an ID3 tag 
- * (either V1 or V2, either header and footer) or not.
- *
- * @param path a path to the file to check
- * @return true if the file has an ID3 tag, false otherwise
- */
-static gboolean hasid3tag(gchar *path)
-{
-  gint fd;
-  guchar tag[3];
-  gboolean result = FALSE;
-  
-#if !GLIB_CHECK_VERSION(2,6,0)  
-  fd = (gint) open(path, READONLY_FLAGS, 0);
-#else
-  fd = (gint) g_open(path, READONLY_FLAGS, 0);
-#endif
-  if (fd >= 0) {
-    /* First check for a header */
-    if(read(fd, tag, 3) == 3) {
-      if (gnomad_debug != 0) {
-	g_print("Checking for header ID3v2 tag...\n");
-      }
-      if (tag[0] == 'I' &&
-	  tag[1] == 'D' &&
-	  tag[2] == '3') {
-	result = TRUE;	
-      } else {
-	/* Seek to end, check for footer */
-	if (lseek(fd, -10, SEEK_END) > 0) {
-	  if (read(fd, tag, 3) == 3) {
-	    if (gnomad_debug != 0) {
-	      g_print("Checking for footer ID3v2 tag...\n");
-	    }
-	    if (tag[0] == '3' &&
-		tag[1] == 'D' &&
-		tag[2] == 'I') {
-	      result = TRUE;
-	    } else {
-	      /* Seek to end, and check for ID3v1 tag */
-	      if (lseek(fd, -128, SEEK_END) > 0) {
-		if (read(fd, tag, 3) == 3) {
-		  if (gnomad_debug != 0) {
-		    g_print("Checking for ID3v1 tag...\n");
-		  }
-		  if (tag[0] == 'T' &&
-		      tag[1] == 'A' &&
-		      tag[2] == 'G') {
-		    result = TRUE;
-		  }
-		}
-	      }
-	    }
-	  }
-	}
-      }
-    }
-    close(fd);
-  }
-  if (gnomad_debug != 0) {
-    g_print(result ? "%s has ID3 tag.\n" : "%s has no ID3 tag.\n", path);
-  }
-  return result;
-}
-
 /*
  * This function checks if a RIFF header exists at the beginning of 
  * the *data buffer. In that case its size is returned. The size
@@ -263,7 +201,7 @@ setFrameText(struct id3_tag *tag,
     return;
 
   if (gnomad_debug != 0) {  
-    g_print("Updating id3 frame (enc: %d): %s: ", encoding, frame_name, data);
+    g_print("Updating id3 frame (enc: %d): %s: ", encoding, frame_name);
     hexdump((unsigned char *) data, strlen(data));
     g_print(" %s\n", data);
   }
@@ -444,7 +382,7 @@ setGenre(struct id3_tag *tag, gchar *genre, enum id3_field_textencoding encoding
 static void
 setSonglen(struct id3_tag *tag, gchar *length, enum id3_field_textencoding encoding, gboolean override)
 {
-  guint seconds;
+  guint32 seconds;
   gchar *tmp;
 
   seconds = mmss_to_seconds(length);
@@ -452,7 +390,7 @@ setSonglen(struct id3_tag *tag, gchar *length, enum id3_field_textencoding encod
     // Convert seconds to milliseconds
     seconds *= 1000;
     // Print the length to a string
-    tmp = g_strdup_printf("%lu", seconds);
+    tmp = g_strdup_printf("%" PRIguint32, seconds);
     setFrameText(tag, "TLEN", tmp, encoding, override);
     g_free(tmp);
   }
@@ -584,19 +522,20 @@ getTracknum(struct id3_tag *tag)
 	break;
       }
     }
-    strncpy(trackno, posstr, sizeof(trackno));
+    strncpy(trackno, posstr, sizeof(trackno)-1);
+    trackno[sizeof(trackno)-1] = '\0';
     if (strlen(trackstr) == 1) {
-      strcat(trackno, "0");
+      strncat(trackno, "0", sizeof(trackno)-1-strlen(trackno));
     }
-    strncat(trackno, trackstr, sizeof(trackno));
+    strncat(trackno, trackstr, sizeof(trackno)-1-strlen(trackno));
     g_free(trackstr);
     g_free(posstr);
   } else {
-    strncpy(trackno, trackstr, sizeof(trackno));
+    strncpy(trackno, trackstr, sizeof(trackno)-1);
+    trackno[sizeof(trackno)-1] = '\0';
     g_free(trackstr);
   }
   // Terminate and return
-  trackno[sizeof(trackno)-1] = '\0';
   return g_strdup(trackno);
 }
 
@@ -900,7 +839,6 @@ get_tag_for_mp3file (metadata_t *meta)
   struct id3_file *fh;
   struct id3_tag *tag;
   gchar *tracknum;
-  gchar *tmp;
   gchar *tmppath;
   gint songlen;
 
@@ -933,7 +871,7 @@ get_tag_for_mp3file (metadata_t *meta)
   meta->title = getTitle(tag);
   meta->album = getAlbum(tag);
   meta->genre = getGenre(tag);
-  meta->year = string_to_guint(getYear(tag));
+  meta->year = string_to_guint32(getYear(tag));
 
   /* If there is a songlength tag it will take
    * precedence over any length calculated from
@@ -946,7 +884,7 @@ get_tag_for_mp3file (metadata_t *meta)
   }
 
   tracknum = getTracknum(tag);
-  meta->trackno = string_to_guint(tracknum);
+  meta->trackno = string_to_guint32(tracknum);
   g_free(tracknum);
   meta->filename = getOrigFilename(tag);
 
@@ -1020,7 +958,7 @@ set_tag_for_mp3file (metadata_t *meta, gboolean override)
   if (meta->year != 0) {
     gchar *tmp;
 
-    tmp = g_strdup_printf("%lu", meta->year);
+    tmp = g_strdup_printf("%" PRIguint32, meta->year);
     setYear(tag, tmp, encoding, override);
     g_free(tmp);
   }
@@ -1047,7 +985,7 @@ set_tag_for_mp3file (metadata_t *meta, gboolean override)
   id3_tag_options(tag, ID3_TAG_OPTION_ID3V1, 0);
   tagv2len = id3_tag_render(tag, tagv2);
   if (gnomad_debug != 0) {
-    g_print("Rendered ID3v2 tag, length %d (0x%x) bytes:\n", tagv2len, tagv2len);
+    g_print("Rendered ID3v2 tag, length %lu (0x%lx) bytes:\n", tagv2len, tagv2len);
     hexdump(tagv2, tagv2len);
   }
 
