@@ -833,7 +833,7 @@ static void add_to_playlist_ok_button (GtkButton *button,
   }
   /* g_print("Calling add_tracks_to_playlists()\n"); */
   add_tracks_to_playlists(listlist, metalist);
-  build_playlist_tree(playlist_widgets.pltreestore);
+  build_playlist_tree();
   /* Free any used memory */
   g_list_free(listlist);
   g_list_free(selected_target_playlists);
